@@ -12,6 +12,7 @@ namespace Ui
 class MainWindow;
 }
 class RCQTextEdit;
+class UsbManager;
 
 class MainWindow : public QMainWindow
 {
@@ -28,6 +29,8 @@ private:
     QNetworkReply *currentDownload;
     QTime downloadTime;
     QFile downfile;
+    UsbManager *m_usbmanage;
+
 protected:
     void closeEvent(QCloseEvent *event);
 
@@ -40,6 +43,7 @@ private slots:
     void load_ini();
     void wload_ini();
     void btload_ini();
+    void usbload_ini();
     void checkbootfile();
     void on_pushButton_rulenow_clicked();
     void on_listWidget_real_doubleClicked(QModelIndex index);
@@ -93,10 +97,12 @@ private slots:
     void checkbtmode();
     void wifistatus();
     bool checkmodule(QString nmodule);
+    bool checkini(QString inifile,QString inigroup);
     bool checkdnsmasq();
     bool getBTstatus();
+    bool getforward(bool setcolor);
     int cuttercount(QString row);
-    int cutterint(QString row, int place);
+    int cutterint(QString row, QString sterm, int place);
     QString getBTproperty(QString key);
     QString getBTdevPath();
     QString getlsof();
@@ -104,6 +110,7 @@ private slots:
     QString filterlog(QString linelog);
     QString cutter(QString row, QString cutstr, int place);
     QString getip(QString dev);
+    QString cutsubnet(QString net);
     bool wmode(QString dev);
     QString getfilter(QString ftype);
     QString getpidof(QString pname);
@@ -175,6 +182,19 @@ private slots:
     void on_checkBox_btdiscover_stateChanged(int state);
     void on_pushButton_bridge_clicked();
     void on_pushButton_btstop_clicked();
+    void on_pushButton_usblmodule_clicked();
+
+    void on_pushButton_usbsave_clicked();
+    void on_pushButton_usbstart_clicked();
+    void on_pushButton_usbstop_clicked();
+
+    void dnsmasqinfo();
+
+    void on_pushButton_dnsmasq_restart_clicked();
+    void on_pushButton_dnskillpid_clicked();
+    void on_pushButton_dnsmasq_clicked();
+    void on_pushButton_forward_clicked();
+    void on_tabWidget_main_currentChanged(int index);
 };
 
 #endif // MAINWINDOW_H
